@@ -220,45 +220,17 @@ This package implements the following methods.
 
 =cut
 
-=head2 new
-
-  # given sub { shift + 1 }
-
-  my $code = Data::Object::Code->new(sub { shift + 1 });
-
-The new method expects a code reference and returns a new class instance.
-
-=cut
-
-=head2 self
-
-  my $self = $code->self();
-
-The self method returns the calling object (noop).
-
-=cut
-
-=head2 roles
-
-  # given $code
-
-  $code->roles;
-
-The roles method returns the list of roles attached to object. This method
-returns a L<Data::Object::Array> object.
-
-=cut
-
-=head2 rules
-
-  my $rules = $code->rules();
-
-The rules method returns consumed rules.
-
-=cut
-
 =head2 call
 
+  call(Any $arg1) : Any
+
+The call method executes and returns the result of the code. This method returns
+a data type object to be determined after execution.
+
+=over 4
+
+=item call example
+
   # given sub { (shift // 0) + 1 }
 
   $code->call; # 1
@@ -266,13 +238,24 @@ The rules method returns consumed rules.
   $code->call(1); # 2
   $code->call(2); # 3
 
-The call method executes and returns the result of the code. This method returns
-a data type object to be determined after execution.
+=back
 
 =cut
 
 =head2 compose
 
+  compose(CodeRef $arg1, Any $arg2) : CodeObject
+
+The compose method creates a code reference which executes the first argument
+(another code reference) using the result from executing the code as it's
+argument, and returns a code reference which executes the created code reference
+passing it the remaining arguments when executed. This method returns a
+L<Data::Object::Code> object.
+
+=over 4
+
+=item compose example
+
   # given sub { [@_] }
 
   $code = $code->compose($code, 1,2,3);
@@ -283,16 +266,22 @@ a data type object to be determined after execution.
   $listing->($listing->(@args)); # produces a listing within a listing
   [[@args]] # the result
 
-The compose method creates a code reference which executes the first argument
-(another code reference) using the result from executing the code as it's
-argument, and returns a code reference which executes the created code reference
-passing it the remaining arguments when executed. This method returns a
-L<Data::Object::Code> object.
+=back
 
 =cut
 
 =head2 conjoin
 
+  conjoin(CodeRef $arg1) : CodeObject
+
+The conjoin method creates a code reference which execute the code and the
+argument in a logical AND operation having the code as the lvalue and the
+argument as the rvalue. This method returns a L<Data::Object::Code> object.
+
+=over 4
+
+=item conjoin example
+
   # given sub { $_[0] % 2 }
 
   $code = $code->conjoin(sub { 1 });
@@ -302,39 +291,63 @@ L<Data::Object::Code> object.
   $code->(3); # 1
   $code->(4); # 0
 
-The conjoin method creates a code reference which execute the code and the
-argument in a logical AND operation having the code as the lvalue and the
-argument as the rvalue. This method returns a L<Data::Object::Code> object.
+=back
 
 =cut
 
 =head2 curry
 
+  curry(CodeRef $arg1) : CodeObject
+
+The curry method returns a code reference which executes the code passing it
+the arguments and any additional parameters when executed. This method returns a
+L<Data::Object::Code> object.
+
+=over 4
+
+=item curry example
+
   # given sub { [@_] }
 
   $code = $code->curry(1,2,3);
   $code->(4,5,6); # [1,2,3,4,5,6]
 
-The curry method returns a code reference which executes the code passing it
-the arguments and any additional parameters when executed. This method returns a
-L<Data::Object::Code> object.
+=back
 
 =cut
 
 =head2 defined
 
-  # given $code
-
-  $code->defined; # 1
+  defined() : NumObject
 
 The defined method returns true if the object represents a value that meets the
 criteria for being defined, otherwise it returns false. This method returns a
 L<Data::Object::Number> object.
 
+=over 4
+
+=item defined example
+
+  # given $code
+
+  $code->defined; # 1
+
+=back
+
 =cut
 
 =head2 disjoin
 
+  disjoin(CodeRef $arg1) : CodeRef
+
+The disjoin method creates a code reference which execute the code and the
+argument in a logical OR operation having the code as the lvalue and the
+argument as the rvalue. This method returns a L<Data::Object::Code> object.
+
+=over 4
+
+=item disjoin example
+
   # given sub { $_[0] % 2 }
 
   $code = $code->disjoin(sub { -1 });
@@ -344,33 +357,116 @@ L<Data::Object::Number> object.
   $code->(3); #  1
   $code->(4); # -1
 
-The disjoin method creates a code reference which execute the code and the
-argument in a logical OR operation having the code as the lvalue and the
-argument as the rvalue. This method returns a L<Data::Object::Code> object.
+=back
+
+=cut
+
+=head2 new
+
+  new(CodeRef $arg1) : CodeObject
+
+The new method expects a code reference and returns a new class instance.
+
+=over 4
+
+=item new example
+
+  # given sub { shift + 1 }
+
+  my $code = Data::Object::Code->new(sub { shift + 1 });
+
+=back
 
 =cut
 
 =head2 next
 
-  $code->next;
+  next(Any $arg1) : Any
 
 The next method is an alias to the call method. The naming is especially useful
 (i.e. helps with readability) when used with closure-based iterators. This
 method returns a L<Data::Object::Code> object. This method is an alias to the
 call method.
 
+=over 4
+
+=item next example
+
+  $code->next;
+
+=back
+
 =cut
 
 =head2 rcurry
 
+  rcurry(Any $arg1) : CodeObject
+
+The rcurry method returns a code reference which executes the code passing it
+the any additional parameters and any arguments when executed. This method
+returns a L<Data::Object::Code> object.
+
+=over 4
+
+=item rcurry example
+
   # given sub { [@_] }
 
   $code = $code->rcurry(1,2,3);
   $code->(4,5,6); # [4,5,6,1,2,3]
 
-The rcurry method returns a code reference which executes the code passing it
-the any additional parameters and any arguments when executed. This method
-returns a L<Data::Object::Code> object.
+=back
+
+=cut
+
+=head2 roles
+
+  roles() : ArrayRef
+
+The roles method returns the list of roles attached to object. This method
+returns a L<Data::Object::Array> object.
+
+=over 4
+
+=item roles example
+
+  # given $code
+
+  $code->roles;
+
+=back
+
+=cut
+
+=head2 rules
+
+  rules() : ArrayRef
+
+The rules method returns consumed rules.
+
+=over 4
+
+=item rules example
+
+  my $rules = $code->rules();
+
+=back
+
+=cut
+
+=head2 self
+
+  self() : Object
+
+The self method returns the calling object (noop).
+
+=over 4
+
+=item self example
+
+  my $self = $code->self();
+
+=back
 
 =cut
 
