@@ -147,31 +147,11 @@ sub choose {
     return 'config_rule';
   }
 
-  # config json
-  if (subject($type, 'json')) {
-    return 'config_json';
-  }
-
-  # config path
-  if (subject($type, 'path')) {
-    return 'config_path';
-  }
-
-  # config tmpl
-  if (subject($type, 'tmpl')) {
-    return 'config_tmpl';
-  }
-
   # config try
   if (subject($type, 'try')) {
     return 'config_try';
   }
 
-  # config yaml
-  if (subject($type, 'yaml')) {
-    return 'config_yaml';
-  }
-
   return;
 }
 
@@ -276,31 +256,25 @@ sub config {
     # basics
     prepare_use('strict'),
     prepare_use('warnings'),
-    prepare_use('feature', 'say'),
-    prepare_use('feature', 'state'),
+
+    # say, state, switch, unicode_strings, array_base
+    prepare_use('feature', ':5.14'),
 
     # types and signatures
-    prepare_use('Data::Object::Config::Library'),
-    prepare_use('Data::Object::Config::Signatures'),
+    prepare_use('Data::Object::Library'),
+    prepare_use('Data::Object::Signatures'),
 
     # contextual
     ($_[0] ? @{$_[0]} : ()),
 
-    # tools and functions
+    # tools and functions, and "do" function
     prepare_use('Data::Object::Export'),
 
-    # special function
+    # make special "do" function work
     prepare_use('subs', 'do')
   ]
 }
 
-sub config_cli {
-  [
-    @{config_class()},
-    prepare_call('extends', 'Data::Object::Cli')
-  ]
-}
-
 sub config_array {
   [
     prepare_use('Role::Tiny::With'),
@@ -308,6 +282,20 @@ sub config_array {
   ]
 }
 
+sub config_class {
+  [
+    prepare_use('Data::Object::Class'),
+    prepare_use('Data::Object::ClassHas')
+  ]
+}
+
+sub config_cli {
+  [
+    @{config_class()},
+    prepare_call('extends', 'Data::Object::Cli')
+  ]
+}
+
 sub config_code {
   [
     prepare_use('Role::Tiny::With'),
@@ -350,12 +338,6 @@ sub config_integer {
   ]
 }
 
-sub config_json {
-  [
-    prepare_use('Data::Object::Export', 'data_json')
-  ]
-}
-
 sub config_kind {
   [
     prepare_use('Role::Tiny::With'),
@@ -370,12 +352,6 @@ sub config_number {
   ]
 }
 
-sub config_path {
-  [
-    prepare_use('Data::Object::Export', 'data_path')
-  ]
-}
-
 sub config_regexp {
   [
     prepare_use('Role::Tiny::With'),
@@ -390,6 +366,20 @@ sub config_replace {
   ]
 }
 
+sub config_role {
+  [
+    prepare_use('Data::Object::Role'),
+    prepare_use('Data::Object::RoleHas')
+  ]
+}
+
+sub config_rule {
+  [
+    prepare_use('Data::Object::Rule'),
+    prepare_use('Data::Object::RoleHas')
+  ]
+}
+
 sub config_scalar {
   [
     prepare_use('Role::Tiny::With'),
@@ -407,7 +397,7 @@ sub config_search {
 sub config_state {
   [
     prepare_use('Data::Object::State'),
-    prepare_use('Data::Object::Config::Class', { replace => 1 }, 'has')
+    prepare_use('Data::Object::ClassHas')
   ]
 }
 
@@ -418,12 +408,6 @@ sub config_string {
   ]
 }
 
-sub config_tmpl {
-  [
-    prepare_use('Data::Object::Export', 'data_tmpl')
-  ]
-}
-
 sub config_try {
   [
     prepare_use('Try::Tiny')
@@ -437,12 +421,6 @@ sub config_type {
   ]
 }
 
-sub config_yaml {
-  [
-    prepare_use('Data::Object::Export', 'data_yaml')
-  ]
-}
-
 sub config_undef {
   [
     prepare_use('Role::Tiny::With'),
@@ -450,27 +428,6 @@ sub config_undef {
   ]
 }
 
-sub config_class {
-  [
-    prepare_use('Data::Object::Class'),
-    prepare_use('Data::Object::Config::Class', { replace => 1 }, 'has')
-  ]
-}
-
-sub config_role {
-  [
-    prepare_use('Data::Object::Role'),
-    prepare_use('Data::Object::Config::Role', { replace => 1 }, 'has')
-  ]
-}
-
-sub config_rule {
-  [
-    prepare_use('Data::Object::Rule'),
-    prepare_use('Data::Object::Config::Role', { replace => 1 }, 'has')
-  ]
-}
-
 # experimental!
 sub _process_meta {
   my ($target, $type, $meta) = @_;
@@ -760,23 +717,6 @@ L<Data::Object::Class> which extends L<Data::Object::Integer>.
 
 =cut
 
-=head2 config_json
-
-  config_json() : ArrayRef
-
-The config_json function returns plans for configuring the package to have a
-C<json> function that loads a L<Data::Object::Json> object.
-
-=over 4
-
-=item config_json example
-
-  my $plans = config_json;
-
-=back
-
-=cut
-
 =head2 config_kind
 
   config_kind() : ArrayRef
@@ -811,23 +751,6 @@ L<Data::Object::Class> which extends L<Data::Object::Number>.
 
 =cut
 
-=head2 config_path
-
-  config_path() : ArrayRef
-
-The config_path function returns plans for configuring the package to have a
-C<path> function that loads a L<Data::Object::Path> object.
-
-=over 4
-
-=item config_path example
-
-  my $plans = config_path;
-
-=back
-
-=cut
-
 =head2 config_regexp
 
   config_regexp() : ArrayRef
@@ -964,23 +887,6 @@ L<Data::Object::Class> which extends L<Data::Object::String>.
 
 =cut
 
-=head2 config_tmpl
-
-  config_tmpl() : ArrayRef
-
-The config_tmpl function returns plans for configuring the package to have a
-C<tmpl> function that loads a L<Data::Object::Template> object.
-
-=over 4
-
-=item config_tmpl example
-
-  my $plans = config_tmpl;
-
-=back
-
-=cut
-
 =head2 config_try
 
   config_try() : ArrayRef
@@ -1032,23 +938,6 @@ L<Data::Object::Class> which extends L<Data::Object::Undef>.
 
 =cut
 
-=head2 config_yaml
-
-  config_yaml() : ArrayRef
-
-The config_yaml function returns plans for configuring the package to have a
-C<yaml> function that loads a L<Data::Object::Yaml> object.
-
-=over 4
-
-=item config_yaml example
-
-  my $plans = config_yaml;
-
-=back
-
-=cut
-
 =head2 prepare
 
   prepare(Str $arg1, Str $arg2) : ArrayRef
