@@ -259,150 +259,254 @@ This package implements the following methods.
 
 =cut
 
-=head2 new
-
-  # given 9.9999
-
-  my $float = Data::Object::Float->new(9.9999);
-
-The new method expects a floating-point number and returns a new class instance.
-
-=cut
-
-=head2 roles
-
-  # given $float
-
-  $float->roles;
-
-The roles method returns the list of roles attached to object. This method
-returns a L<Data::Object::Array> object.
-
-=cut
-
-=head2 rules
-
-  my $rules = $float->rules();
-
-The rules method returns consumed rules.
-
-=cut
-
 =head2 defined
 
-  # given $float
-
-  $float->defined; # 1
+  defined() : NumObject
 
 The defined method returns true if the object represents a value that meets the
 criteria for being defined, otherwise it returns false. This method returns a
 L<Data::Object::Number> object.
 
+=over 4
+
+=item defined example
+
+  # given $float
+
+  $float->defined; # 1
+
+=back
+
 =cut
 
 =head2 downto
 
-  # given 1.23
-
-  $float->downto(0); # [1,0]
+  downto(Int $arg1) : ArrayObject
 
 The downto method returns an array reference containing integer decreasing
 values down to and including the limit. This method returns a
 L<Data::Object::Array> object.
 
+=over 4
+
+=item downto example
+
+  # given 1.23
+
+  $float->downto(0); # [1,0]
+
+=back
+
 =cut
 
 =head2 eq
 
+  eq(Any $arg1) : NumObject
+
+The eq method performs a numeric equality operation. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
+=over 4
+
+=item eq example
+
   # given 1.23
 
   $float->eq(1); # 0
 
-The eq method performs a numeric equality operation. This method returns a
-L<Data::Object::Number> object representing a boolean.
+=back
 
 =cut
 
 =head2 ge
 
-  # given 1.23
-
-  $float->ge(1); # 1
+  ge(Any $arg1) : NumObject
 
 The ge method returns true if the argument provided is greater-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
 object.
 
+=over 4
+
+=item ge example
+
+  # given 1.23
+
+  $float->ge(1); # 1
+
+=back
+
 =cut
 
 =head2 gt
 
+  gt(Any $arg1) : NumObject
+
+The gt method performs a numeric greater-than comparison. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
+=over 4
+
+=item gt example
+
   # given 1.23
 
   $float->gt(1); # 1
 
-The gt method performs a numeric greater-than comparison. This method returns a
-L<Data::Object::Number> object representing a boolean.
+=back
 
 =cut
 
 =head2 le
 
-  # given 1.23
-
-  $float->le(1); # 0
+  le(Any $arg1) : NumObject
 
 The le method returns true if the argument provided is less-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
 object.
 
+=over 4
+
+=item le example
+
+  # given 1.23
+
+  $float->le(1); # 0
+
+=back
+
 =cut
 
 =head2 lt
 
+  lt(Any $arg1) : NumObject
+
+The lt method performs a numeric less-than comparison. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
+=over 4
+
+=item lt example
+
   # given 1.23
 
   $float->lt(1.24); # 1
 
-The lt method performs a numeric less-than comparison. This method returns a
-L<Data::Object::Number> object representing a boolean.
+=back
 
 =cut
 
 =head2 ne
 
+  ne(Any $arg1) : NumObject
+
+The ne method performs a numeric equality operation. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
+=over 4
+
+=item ne example
+
   # given 1.23
 
   $float->ne(1); # 1
 
-The ne method performs a numeric equality operation. This method returns a
-L<Data::Object::Number> object representing a boolean.
+=back
+
+=cut
+
+=head2 new
+
+  new(Num $arg1) : FloatObject
+
+The new method expects a floating-point number and returns a new class instance.
+
+=over 4
+
+=item new example
+
+  # given 9.9999
+
+  my $float = Data::Object::Float->new(9.9999);
+
+=back
+
+=cut
+
+=head2 roles
+
+  roles() : ArrayRef
+
+The roles method returns the list of roles attached to object. This method
+returns a L<Data::Object::Array> object.
+
+=over 4
+
+=item roles example
+
+  # given $float
+
+  $float->roles;
+
+=back
+
+=cut
+
+=head2 rules
+
+  rules() : ArrayRef
+
+The rules method returns consumed rules.
+
+=over 4
+
+=item rules example
+
+  my $rules = $float->rules();
+
+=back
 
 =cut
 
 =head2 to
 
-  # given 1.23
-
-  $float->to(2); # [1,2]
-  $float->to(0); # [1,0]
+  to(Int $arg1) : ArrayObject
 
 The to method returns an array reference containing integer increasing or
 decreasing values to and including the limit in ascending or descending order
 based on the value of the floating-point object. This method returns a
 L<Data::Object::Array> object.
 
+=over 4
+
+=item to example
+
+  # given 1.23
+
+  $float->to(2); # [1,2]
+  $float->to(0); # [1,0]
+
+=back
+
 =cut
 
 =head2 upto
 
+  upto(Int $arg1) : Any
+
+The upto method returns an array reference containing integer increasing
+values up to and including the limit. This method returns a
+L<Data::Object::Array> object.
+
+=over 4
+
+=item upto example
+
   # given 1.23
 
   $float->upto(2); # [1,2]
 
-The upto method returns an array reference containing integer increasing
-values up to and including the limit. This method returns a
-L<Data::Object::Array> object.
+=back
 
 =cut
 
