@@ -70,7 +70,7 @@ Data-Object Float Type Constraint
 
 Type constraint for validating L<Data::Object::Float>
 objects. This type constraint is registered in the
-L<Data::Object::Config::Library> type library.
+L<Data::Object::Library> type library.
 
 =cut
 
